@@ -4,6 +4,7 @@ import argparse
 
 import quakeio
 
+
 def build_parser():
     # fmt: off
     parser = argparse.ArgumentParser(
@@ -39,14 +40,14 @@ def build_parser():
         "-f",
         dest="input_format",
         metavar="FORMAT",
-        help="Specity input file format",
+        help="Specify input file format",
         choices=list(quakeio.FILE_TYPES.keys()),
     )
     parser.add_argument(
-        "-t",
+        "-t", "--to",
         dest="write_format",
         metavar="FORMAT",
-        help="Specity output file format",
+        help="Specify output file format",
         default="json",
     )
     parser.add_argument(
@@ -63,7 +64,7 @@ def build_parser():
     )
     formats = parser.add_argument_group("Formats",
         description=f"""
-        yaml, json, csmip
+        yaml, json, csmip, opensees
         """
         # {', '.join(quakeio.FILE_TYPES.keys())}
     )
@@ -94,4 +95,3 @@ def main():
 
 if __name__ == "__main__":
     main()
-
