@@ -2,7 +2,7 @@ import json
 from copy import copy
 from pathlib import Path
 
-from quakeio.core import GroundMotionComponent, GroundMotionEvent
+from quakeio.core import QuakeComponent, QuakeCollection
 from quakeio.utils.parseutils import open_quake
 
 
@@ -16,6 +16,18 @@ class QuakeEncoder(json.JSONEncoder):
             return obj.tolist()
         return json.JSONEncoder.default(self, obj)
 
+def read_basic(data:dict):
+    if "motions" in data:
+        for motion in data["motions"]:
+            for component in motion["components"]:
+                pass
+    else:
+        raise ValueError()
+    pass
+
+def create_series(data):
+    series = data.pop("data")
+    return QuakeSeries(series, meta=data)
 
 def read_json(read_file, **kwds: Unused):
 
@@ -30,6 +42,10 @@ def write_json(write_file, ground_motion, indent=4, summarize=False, **kwds):
     except BrokenPipeError:
         pass
 
+def dumps_json(ground_motion, indent=4, summarize=False, **kwds):
+    ground_motion = ground_motion.serialize(serialize_data=not summarize)
+    return json.dumps(ground_motion, indent=indent, cls=QuakeEncoder)
+
 
 def read_yaml(read_file, **k):
     import yaml
@@ -48,8 +64,6 @@ def write_yaml(write_file, ground_motion, summarize=False, **kwds):
         yaml.dump(ground_motion, f)
 
 
-
-
 FILE_TYPES = {
     "json": {"read": read_json, "write": write_json},
     "yaml": {"read": read_yaml, "write": write_yaml},
