@@ -2,7 +2,7 @@ import re
 
 import numpy as np
 
-from quakeio.core import GroundMotionSeries
+from quakeio.core import QuakeSeries
 from quakeio.utils.parseutils import open_quake
 
 RE_TIME_STEP = re.compile(r"DT=\s+(.*)SEC")
@@ -14,7 +14,7 @@ def read_nga(read_file, *args, **kwds):
     dt = float(RE_TIME_STEP.search(header[-1]).group(1).strip())
     series_type = header[-2][:5].lower()
     accel = np.genfromtxt(read_file, skip_header=4, skip_footer=1).flatten()
-    return GroundMotionSeries(
+    return QuakeSeries(
         accel, dict(time_step=dt, series_type=series_type, units="g")
     )
 
@@ -22,6 +22,6 @@ def read_nga(read_file, *args, **kwds):
 FILE_TYPES = {
     "nga.at2": {
         "read": read_nga,
-        "type": GroundMotionSeries,
+        "type": QuakeSeries,
     }
 }
